/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#include "distanceinputdialog.h"

DistanceInputDialog::DistanceInputDialog(int distCount, QWidget *parent)
    : QDialog(parent)
{
    QGridLayout *layout = new QGridLayout;
    transformButton = new QPushButton(tr("Transform"), this);
    sepDist1SpinBox = new QDoubleSpinBox(this);
    sepDist1SpinBox->setDecimals(3);

    newScaleSpinBox = new QDoubleSpinBox(this);
    newScaleSpinBox->setDecimals(4);
    newScaleSpinBox->setRange(0.0, 100.0);

    QLabel *newScaleLabel = new QLabel(tr("Type a new pixel size. 1 pixel ="), this);
    QLabel *meterLabel = new QLabel(tr("m"), this);

    if(distCount == 1)
    {
        setWindowTitle(tr("Type measured distance"));
        QLabel *distLabel = new QLabel(tr("Measured distance [m]:"), this);

        rotateCheckBox = new QCheckBox(tr("The distance is vertical"), this);
        rotateCheckBox->setChecked(false);

        layout->addWidget(distLabel, 0, 0);
        layout->addWidget(sepDist1SpinBox, 0, 1);
        layout->addWidget(newScaleLabel, 1, 0);
        layout->addWidget(newScaleSpinBox, 1, 1);
        layout->addWidget(meterLabel, 1, 2);
        layout->addWidget(rotateCheckBox, 2, 0);
    }
    else
    {
        setWindowTitle(tr("Type Vertical And Horizontal Distance"));
        QLabel *verticalLabel = new QLabel(tr("Measured vertical [m]:"), this);
        QLabel *horizontalLabel = new QLabel(tr("Measured horizontal [m]:"), this);

        sepDist2SpinBox = new QDoubleSpinBox(this);
        sepDist2SpinBox->setDecimals(3);

        layout->addWidget(verticalLabel, 0, 0);
        layout->addWidget(sepDist1SpinBox, 0, 1);
        layout->addWidget(horizontalLabel, 1, 0);
        layout->addWidget(sepDist2SpinBox, 1, 1);
        layout->addWidget(newScaleLabel, 2, 0);
        layout->addWidget(newScaleSpinBox, 2, 1);
        layout->addWidget(meterLabel, 2, 2);
    }

    layout->addWidget(transformButton, 3, 1);

    Qt::WindowFlags flags;
    flags = Qt::Dialog;
    flags |= Qt::WindowCloseButtonHint;

    setWindowFlags(flags);
    setLayout(layout);
    setModal(true);
}

QPushButton* DistanceInputDialog::getTransformButton()
{
    return transformButton;
}

QDoubleSpinBox* DistanceInputDialog::getSepDist1SpinBox()
{
    return sepDist1SpinBox;
}

QDoubleSpinBox* DistanceInputDialog::getSepDist2SpinBox()
{
    return sepDist2SpinBox;
}

QDoubleSpinBox* DistanceInputDialog::getNewScaleSpinBox()
{
    return newScaleSpinBox;
}

double DistanceInputDialog::getInputPixelSize()
{
    return inputPixelSize;
}

void DistanceInputDialog::setInputPixelSize(double size)
{
    inputPixelSize = size;
}

QCheckBox* DistanceInputDialog::getRotateCheckBox()
{
    return rotateCheckBox;
}
