/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#include "distorsiondialog.h"

DistorsionDialog::DistorsionDialog(QWidget *parent)
    : QDialog(parent)
{
    formatW = new QDoubleSpinBox(this);
    formatH = new QDoubleSpinBox(this);
    ppX = new QDoubleSpinBox(this);
    ppY = new QDoubleSpinBox(this);
    K1 = new QDoubleSpinBox(this);
    K2 = new QDoubleSpinBox(this);
    K3 = new QDoubleSpinBox(this);
    P1 = new QDoubleSpinBox(this);
    P2 = new QDoubleSpinBox(this);

    formatW->setDecimals(4);
    formatW->setRange(0.0, 100.0);

    formatH->setDecimals(4);
    formatH->setRange(0.0, 100.0);

    ppX->setDecimals(4);
    ppX->setRange(0.0, 100.0);

    ppY->setDecimals(4);
    ppY->setRange(0.0, 100.0);

    K1->setDecimals(10);
    K1->setRange(-100.0, 100.0);

    K2->setDecimals(10);
    K2->setRange(-100.0, 100.0);

    K3->setDecimals(10);
    K3->setRange(-100.0, 100.0);

    P1->setDecimals(10);
    P1->setRange(-100.0, 100.0);

    P2->setDecimals(10);
    P2->setRange(-100.0, 100.0);

    transformButton = new QPushButton(tr("Transform"), this);

    QLabel *formatLabel = new QLabel(tr("Format Size:"), this);
    QLabel *formatWLabel = new QLabel(tr("Width [mm]:"), this);
    QLabel *formatHLabel = new QLabel(tr("Height [mm]:"), this);
    QLabel *ppLabel = new QLabel(tr("Principal Point:"), this);
    QLabel *xLabel = new QLabel("x [mm]:", this);
    QLabel *yLabel = new QLabel("y [mm]:", this);
    QLabel *radialLabel = new QLabel(tr("Coefficients of radial part:"), this);
    QLabel *tangencialLabel = new QLabel(tr("Coefficients of tangencial part:"), this);
    QLabel *K1Label = new QLabel("K1:", this);
    QLabel *K2Label = new QLabel("K2:", this);
    QLabel *K3Label = new QLabel("K3:", this);
    QLabel *P1Label = new QLabel("P1:", this);
    QLabel *P2Label = new QLabel("P2:", this);

    formatLabel->setFont(QFont("Arial", 9, QFont::Bold));
    ppLabel->setFont(QFont("Arial", 9, QFont::Bold));
    radialLabel->setFont(QFont("Arial", 9, QFont::Bold));
    tangencialLabel->setFont(QFont("Arial", 9, QFont::Bold));

    QGridLayout *layout = new QGridLayout;
    QGridLayout *formatLayout = new QGridLayout;
    QGridLayout *ppLayout = new QGridLayout;
    QGridLayout *radialLayout = new QGridLayout;
    QGridLayout *tangencialLayout = new QGridLayout;

    QSpacerItem *spacer = new QSpacerItem(50, 50, QSizePolicy::Expanding, QSizePolicy::Minimum);

    formatLayout->addWidget(formatWLabel, 0, 0);
    formatLayout->addWidget(formatW, 0, 1);
    formatLayout->addWidget(formatHLabel, 1, 0);
    formatLayout->addWidget(formatH, 1, 1);

    ppLayout->addWidget(xLabel, 0, 0);
    ppLayout->addWidget(ppX, 0, 1);
    ppLayout->addWidget(yLabel, 1, 0);
    ppLayout->addWidget(ppY, 1, 1);

    radialLayout->addWidget(K1Label, 0, 0);
    radialLayout->addWidget(K1, 0, 1);
    radialLayout->addWidget(K2Label, 1, 0);
    radialLayout->addWidget(K2, 1, 1);
    radialLayout->addWidget(K3Label, 2, 0);
    radialLayout->addWidget(K3, 2, 1);

    tangencialLayout->addWidget(P1Label, 0, 0);
    tangencialLayout->addWidget(P1, 0, 1);
    tangencialLayout->addWidget(P2Label, 1, 0);
    tangencialLayout->addWidget(P2, 1, 1);

    layout->addWidget(ppLabel, 0, 0);
    layout->addLayout(ppLayout, 1, 0);
    layout->addWidget(formatLabel, 0, 2);
    layout->addLayout(formatLayout, 1, 2);
    layout->addWidget(radialLabel, 3, 0);
    layout->addLayout(radialLayout, 4, 0);
    layout->addWidget(tangencialLabel, 3, 2);
    layout->addLayout(tangencialLayout, 4, 2);
    layout->addWidget(transformButton, 5, 2);
    layout->addItem(spacer, 2, 1);

    Qt::WindowFlags flags;
    flags = Qt::Dialog;
    flags |= Qt::WindowCloseButtonHint;

    setWindowFlags(flags);
    setWindowTitle(tr("Lens Parameters"));
    setLayout(layout);
    setModal(true);
}

QDoubleSpinBox* DistorsionDialog::getW()
{
    return formatW;
}

QDoubleSpinBox* DistorsionDialog::getH()
{
    return formatH;
}

QDoubleSpinBox* DistorsionDialog::getPPX()
{
    return ppX;
}

QDoubleSpinBox* DistorsionDialog::getPPY()
{
    return ppY;
}

QDoubleSpinBox* DistorsionDialog::getK1()
{
    return K1;
}

QDoubleSpinBox* DistorsionDialog::getK2()
{
    return K2;
}

QDoubleSpinBox* DistorsionDialog::getK3()
{
    return K3;
}

QDoubleSpinBox* DistorsionDialog::getP1()
{
    return P1;
}

QDoubleSpinBox* DistorsionDialog::getP2()
{
    return P2;
}

QPushButton* DistorsionDialog::getButton()
{
    return transformButton;
}
