/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#ifndef MAPLAYOUTDIALOG_H
#define MAPLAYOUTDIALOG_H

#include<QtGui>

class MapLayoutDialog : public QDialog
{
    Q_OBJECT

public slots:
    void showPaper();
    void changeTool();
    void changeTextSize();
    void drawPrintPixmap();

    QSize paperSize();

    QPushButton* getBackButton();

public:
    MapLayoutDialog(QImage *photoMap, QRect *mapRect, double pixSize, QString filePath,QWidget *parent = 0);

private:
    void closeEvent(QCloseEvent *closeEvent);
    void addMapItem(int x, int y);
    void addTitleItem(int x, int y);
    void addDescriptionItem(int x, int y);
    void printImage();

    bool eventFilter(QObject *obj, QEvent *event);

    QComboBox *paperComboBox;
    QComboBox *orientationComboBox;

    QSpinBox *printScaleBox;
    QSpinBox *titleSizeBox;
    QSpinBox *descriptionSizeBox;

    QLineEdit *titleLineEdit;
    QLineEdit *descriptionLineEdit;

    QPushButton *printButton;
    QPushButton *backButton;

    QRadioButton *mapRadioButton;
    QRadioButton *titleRadioButton;
    QRadioButton *descriptionRadioButton;

    QGraphicsView *graphicsView;
    QGraphicsScene *graphicsScene;

    QImage *paper;
    QImage *map;
    QImage *image;

    QGraphicsPixmapItem *pixmapItem;
    QGraphicsPixmapItem *mapItem;

    QGraphicsRectItem *rectItem;
    QGraphicsRectItem *backgroundItem;

    QGraphicsTextItem *titleItem;
    QGraphicsTextItem *descriptionItem;

    QRect *rect;

    QLabel *moveTitleLabel;
    QLabel *moveDescrpLabel;
    QLabel *previewTitleLabel;
    QLabel *pixelSizeLabel;
    QLabel *paperLabel;
    QLabel *orientationLabel;
    QLabel *scaleLabel;
    QLabel *titleLabel;
    QLabel *titleSizeLabel;
    QLabel *descriptionLabel;
    QLabel *descriptionSizeLabel;

    QString dir;

    int w;
    int h;

    double pixelSize;

    bool mapFixed;
};

#endif // MAPLAYOUTDIALOG_H
