/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#include "measuretool.h"

MeasureTool::MeasureTool()
{
    shortcutLabel = new QLabel(tr("'Q' key = forward, 'A' key = back"), this);

    pointNumberSpinBox = new QSpinBox(this);
    pointNumberSpinBox->setRange(1, 2);

    pointMask = QBitmap("images/points/mask.bmp");

    pointLabel = new QLabel(this);
    valueWasChanged(1);

    distanceLabel = new QLabel(tr("DISTANCE:"), this);
    distanceLabel->setFont(QFont("Arial", 9, QFont::Bold));
    distanceLabel->setAlignment(Qt::AlignTop);

    exitButton = new QPushButton(tr("Exit Measurement"), this);

    QHBoxLayout *hLayout = new QHBoxLayout;
    QVBoxLayout *layout = new QVBoxLayout;

    hLayout->addWidget(pointNumberSpinBox);
    hLayout->addWidget(pointLabel);

    layout->addWidget(shortcutLabel);
    layout->addLayout(hLayout);
    layout->addWidget(distanceLabel);
    layout->addWidget(exitButton);

    setLayout(layout);
    adjustSize();
    setMaximumSize(this->width(), this->height());

    connect(pointNumberSpinBox, SIGNAL(valueChanged(int)), this, SLOT(valueWasChanged(int)));
}

void MeasureTool::valueWasChanged(int value)
{
    QString pointFile("images/points/");
    pointFile.append(QString::number(value)).append(".bmp");

    QPixmap *pixmap = new QPixmap(pointFile);

    pixmap->setMask(pointMask);
    pointLabel->setPixmap(*pixmap);

    if(value == 1)
    {
        firstPoint();
    }
    else
    {
        secondPoint();
    }

    delete pixmap;
}

void MeasureTool::computeDistance(int x1, int y1, int x2, int y2, double pixelSize)
{
    double distance;
    distance = sqrt((x2 - x1) * (x2 - x1) + (y2 - y1) * (y2 - y1)) * pixelSize;

    QString distanceString(tr("DISTANCE: "));
    distanceString.append(QString::number(distance, 'f', 3)).append(" m");

    distanceLabel->setText(distanceString);
}

QPushButton* MeasureTool::getExitButton()
{
    return exitButton;
}

QLabel* MeasureTool::getDistanceLabel()
{
    return distanceLabel;
}

QSpinBox* MeasureTool::getSpinBox()
{
    return pointNumberSpinBox;
}
