/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#ifndef MEMORYCLASS_H
#define MEMORYCLASS_H

#include <QtGui>
#include <eigen2/Eigen/Core>
#include <eigen2/Eigen/lu>

USING_PART_OF_NAMESPACE_EIGEN

class MemoryClass
{
public:
    MemoryClass();

    void setNetworkDistances(Matrix<double, 6, 1> dist);
    void setNetworkCoordinates(Matrix<double, 4, 2> coords);
    void setActionName(QString name);
    void setDiagonal(int diag);
    void setPixelSize(double size);
    void setObjectCoordinates(Matrix<double, 9, 2> coords);
    void setObjCoordsZero();
    void setPreviousImage(QImage *image);
    void addNumberOfChanges();
    void reduceNumberOfChanges();
    void setNumberOfChanges(int number);
    void setPreviousPixelSize(double size);
    void setObjectCoordsKey(Matrix<double, 2, 1> key);
    void setCornersCrd(bool crd);
    void setPreviousCornersCrd(bool crd);
    void setPreviousObjectCoordsKey(Matrix<double, 2, 1> key);

    Matrix<double, 6, 1> getNetworkDistances();
    Matrix<double, 4, 2> getNetworkCoordinates();
    Matrix<double, 9, 2> getObjectCoordinates();
    Matrix<double, 2, 1> getObjectCoordsKey();
    Matrix<double, 2, 1> getPreviousObjectCoordsKey();

    QString getActionName();
    QImage* getPreviousImage();

    int getDiagonal();
    int getNumberOfChanges();

    double getPixelSize();
    double getPreviousPixelSize();

    bool getCornersCrd();
    bool getPreviousCornersCrd();

private:
    Matrix<double, 6, 1> networkDistances;
    Matrix<double, 4, 2> networkCoordinates;
    Matrix<double, 9, 2> objectCoordinates;
    Matrix<double, 2, 1> objectCoordsKey;
    Matrix<double, 2, 1> previousObjectCoordsKey;

    QString actionName;

    QImage *previousImage;

    int diagonal;
    int numberOfChanges;

    double pixelSize;
    double previousPixelSize;

    bool previousCornersCrd;
    bool cornersCrd;
};

#endif // MEMORYCLASS_H
