/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#include "overview.h"

Overview::Overview()
{
    frame = new QFrame(this);
}

void Overview::setOverview(QImage *image, QSize windowSize, QPoint windowPosition)
{
    setPixmap(QPixmap::fromImage(image->scaled(400, 400, Qt::KeepAspectRatio, Qt::FastTransformation)));
    setMaximumSize(image->scaled(400, 400, Qt::KeepAspectRatio, Qt::FastTransformation).size());

    QColor frameColor(220, 0, 0, 255);
    QPalette palette;

    palette.setColor(QPalette::WindowText, frameColor);

    frame->setFrameShape(QFrame::WinPanel);
    frame->setFrameShadow(QFrame::Plain);
    frame->setPalette(palette);

    moveFrame(image->size(), windowSize, windowPosition);
}

void Overview::moveFrame(QSize imageSize, QSize windowSize, QPoint windowPosition)
{
    int x, y, w, h;

    x = - windowPosition.x() * this->width() / imageSize.width();
    y = - windowPosition.y() * this->height() / imageSize.height();
    w = windowSize.width() * this->width() / imageSize.width();
    h = windowSize.height() * this->height() / imageSize.height();

    frame->setGeometry(x, y, w, h);
}

QFrame* Overview::getFrame()
{
    return frame;
}
